@@ -54,8 +54,7 @@ def parse_config():
             with open(cfg_file, 'r') as config_file:
                 config = yaml.safe_load(config_file)
                 file = cfg_file
-                file_path = os.path.abspath(cfg_file)
-
+                # file_path = os.path.abspath(cfg_file)
                 # print(f"Config {cfg_file} found at full path {os.path.abspath(cfg_file)}")
                 break
     if not config:
@@ -75,4 +74,4 @@ def parse_config():
     except (OSError, yaml.parser.ParserError, yaml.scanner.ScannerError) as e:
         print(f"Error: Failed to write config file. {e}")
 
-    return config, file_path
+    return config
